{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "default": "merged_changes.csv",
                    "type": "string",
                    "id": "#main/align_c"
                },
                {
                    "default": "merged_metadata.csv",
                    "type": "string",
                    "id": "#main/align_m"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/gs"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/ocr"
                }
            ],
            "steps": [
                {
                    "run": "#align.cwl",
                    "in": [
                        {
                            "source": "#main/ocr",
                            "id": "#main/align-1/file1"
                        },
                        {
                            "source": "#main/gs",
                            "id": "#main/align-1/file2"
                        }
                    ],
                    "out": [
                        "#main/align-1/changes",
                        "#main/align-1/metadata"
                    ],
                    "scatter": [
                        "#main/align-1/file1",
                        "#main/align-1/file2"
                    ],
                    "scatterMethod": "dotproduct",
                    "id": "#main/align-1"
                },
                {
                    "run": "#char-align.cwl",
                    "in": [
                        {
                            "source": "#main/gs",
                            "id": "#main/char-align-1/gs_text"
                        },
                        {
                            "source": "#main/align-1/metadata",
                            "id": "#main/char-align-1/metadata"
                        },
                        {
                            "source": "#main/ocr",
                            "id": "#main/char-align-1/ocr_text"
                        }
                    ],
                    "out": [
                        "#main/char-align-1/out_file"
                    ],
                    "scatter": [
                        "#main/char-align-1/gs_text",
                        "#main/char-align-1/ocr_text",
                        "#main/char-align-1/metadata"
                    ],
                    "scatterMethod": "dotproduct",
                    "id": "#main/char-align-1"
                },
                {
                    "run": "#merge-json.cwl",
                    "in": [
                        {
                            "source": "#main/align-1/metadata",
                            "id": "#main/merge-json-4/in_files"
                        },
                        {
                            "source": "#main/align_m",
                            "id": "#main/merge-json-4/name"
                        }
                    ],
                    "out": [
                        "#main/merge-json-4/merged"
                    ],
                    "id": "#main/merge-json-4"
                },
                {
                    "run": "#merge-json.cwl",
                    "in": [
                        {
                            "source": "#main/align-1/changes",
                            "id": "#main/merge-json-5/in_files"
                        },
                        {
                            "source": "#main/align_c",
                            "id": "#main/merge-json-5/name"
                        }
                    ],
                    "out": [
                        "#main/merge-json-5/merged"
                    ],
                    "id": "#main/merge-json-5"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "items": "File",
                        "type": "array"
                    },
                    "outputSource": "#main/char-align-1/out_file",
                    "id": "#main/alignments"
                },
                {
                    "type": "File",
                    "outputSource": "#main/merge-json-5/merged",
                    "id": "#main/changes"
                },
                {
                    "type": "File",
                    "outputSource": "#main/merge-json-4/merged",
                    "id": "#main/metadata"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "python",
                "/align.py"
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "nlppln/edlib-align:0.1.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#align.cwl/file1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#align.cwl/file2"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "--out_dir=",
                        "separate": false
                    },
                    "id": "#align.cwl/out_dir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*-changes.json"
                    },
                    "id": "#align.cwl/changes"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*-metadata.json"
                    },
                    "id": "#align.cwl/metadata"
                }
            ],
            "id": "#align.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "python",
                "-m",
                "ochre.char_align"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#char-align.cwl/gs_text"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#char-align.cwl/metadata"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#char-align.cwl/ocr_text"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.json"
                    },
                    "id": "#char-align.cwl/out_file"
                }
            ],
            "id": "#char-align.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "python",
                "-m",
                "ochre.merge_json"
            ],
            "requirements": [
                {
                    "listing": "$(inputs.in_files)",
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": 1
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#merge-json.cwl/in_files"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--name=",
                        "separate": false
                    },
                    "id": "#merge-json.cwl/name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.csv"
                    },
                    "id": "#merge-json.cwl/merged"
                }
            ],
            "id": "#merge-json.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
